@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>                      */
+/* Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>                      */
 
 #ifndef FILTERS_H
 #define FILTERS_H
@@ -31,13 +31,11 @@
 
 #include <QDir>
 
-namespace MailImporter
-{
+namespace MailImporter {
 class MAILIMPORTER_EXPORT Filter
 {
 public:
-    explicit Filter(const QString &name, const QString &author,
-                    const QString &info = QString());
+    explicit Filter(const QString &name, const QString &author, const QString &info = QString());
     virtual ~Filter();
     virtual void import() = 0;
 
@@ -65,16 +63,11 @@ public:
 
 protected:
     static int countDirectory(const QDir &dir, bool searchHiddenDirectory);
-    bool importMessage(const QString &folderName,
-                       const QString &msgPath,
-                       bool duplicateCheck,
-                       MailImporter::MessageStatus status = MailImporter::MessageStatus());
+    bool importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, MailImporter::MessageStatus status = MailImporter::MessageStatus());
 private:
     class Private;
     Private *const d;
 };
-
 }
 
 #endif
-
