@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -31,8 +31,8 @@ public:
     {
     }
 
-    int mImportDirDone;
-    int mTotalDir;
+    int mImportDirDone = 0;
+    int mTotalDir = 0;
 };
 /** Default constructor. */
 FilterBalsa::FilterBalsa()
@@ -52,6 +52,15 @@ FilterBalsa::~FilterBalsa()
     delete d;
 }
 
+QString FilterBalsa::isMailerFound()
+{
+    QDir directory(FilterBalsa::defaultSettingsPath());
+    if (directory.exists()) {
+        return i18nc("name of balsa application", "Balsa");
+    }
+    return {};
+}
+
 QString FilterBalsa::defaultSettingsPath()
 {
     return QDir::homePath() + QLatin1String("/.balsa/");
