@@ -37,13 +37,11 @@ class MailImporter::FilterKMailArchivePrivate
 {
 public:
     FilterKMailArchivePrivate()
-        : mTotalFiles(0)
-        , mFilesDone(0)
     {
     }
 
-    int mTotalFiles;
-    int mFilesDone;
+    int mTotalFiles = 0;
+    int mFilesDone = 0;
 };
 FilterKMailArchive::FilterKMailArchive()
     : Filter(i18n("Import KMail Archive File"),
@@ -175,7 +173,8 @@ int FilterKMailArchive::countFiles(const KArchiveDirectory *directory) const
 void FilterKMailArchive::import()
 {
     const QString archiveFile
-        = QFileDialog::getOpenFileName(filterInfo()->parentWidget(), i18n("Select KMail Archive File to Import"), QString(), i18n("KMail Archive Files (*.tar *.tar.gz *.tar.bz2 *.zip)"));
+        = QFileDialog::getOpenFileName(filterInfo()->parentWidget(), i18n("Select KMail Archive File to Import"),
+                                       QString(), QStringLiteral("%1 (*.tar *.tar.gz *.tar.bz2 *.zip)").arg(i18n("KMail Archive Files ")));
     if (archiveFile.isEmpty()) {
         filterInfo()->alert(i18n("Please select an archive file that should be imported."));
         return;
