@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,8 +20,7 @@
 
 #include "filters.h"
 
-namespace MailImporter
-{
+namespace MailImporter {
 class MAILIMPORTER_EXPORT FilterMailmanGzip : public Filter
 {
 public:
@@ -29,7 +28,7 @@ public:
     ~FilterMailmanGzip();
 
     void importMails(const QStringList &filenames);
-    void import() Q_DECL_OVERRIDE;
+    void import() override;
 };
 }
 
