@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,9 +25,10 @@ class FilterThunderBirdAbstract : public MailImporter::FilterThunderbird
 public:
     FilterThunderBirdAbstract()
     {
-
     }
-    QString settingsPath() Q_DECL_OVERRIDE {
+
+    QString settingsPath() override
+    {
         return MailImporter::FilterThunderbird::settingsPath();
     }
 };
@@ -35,12 +36,10 @@ public:
 FilterThunderBirdTest::FilterThunderBirdTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 FilterThunderBirdTest::~FilterThunderBirdTest()
 {
-
 }
 
 void FilterThunderBirdTest::shouldHaveDefaultSettingsPath()
@@ -51,7 +50,6 @@ void FilterThunderBirdTest::shouldHaveDefaultSettingsPath()
 
 void FilterThunderBirdTest::shouldImportData()
 {
-
 }
 
 void FilterThunderBirdTest::canNotImportDataEmptyPath()
